---
stage: none
group: none
info: To determine the technical writer assigned to the Stage/Group associated with this page, see https://handbook.gitlab.com/handbook/product/ux/technical-writing/#assignments
noindex: true
title: Breaking change deployments on GitLab.com
---

Changes are deployed continuously to GitLab.com. However, breaking changes
can require more time to prepare for.

In the month before the GitLab 18.0 release, breaking changes will be deployed
during three time windows. The following tables list when each breaking change will be deployed.

<!--
Do not edit this page directly.
This page is generated by lib/tasks/gitlab/docs/compile_windows.rake and
from the yaml files in /data/deprecations.
To update this file, run: bin/rake gitlab:docs:compile_windows
-->
## Window 1

This window takes place on April 21 - 23, 2025 from 09:00 UTC to 22:00 UTC.

| Deprecation | Impact | Stage | Scope | Check potential impact |
|-------------|--------|-------|-------|------------------------|
| [CI/CD job token - **Limit access from your project** setting removal](deprecations.md#cicd-job-token---limit-access-from-your-project-setting-removal) | High | Software supply chain security | Project |  |
| [CI/CD job token - **Authorized groups and projects** allowlist enforcement](deprecations.md#cicd-job-token---authorized-groups-and-projects-allowlist-enforcement) | High | Software supply chain security | Project | Use the [Authentication Log](../ci/jobs/ci_job_token.md#job-token-authentication-log) to verify which projects are authenticating with your project. |
| [Deprecate License Scanning CI/CD artifact report type](deprecations.md#deprecate-license-scanning-cicd-artifact-report-type) | Low | Secure | Project |  |
| [OpenTofu CI/CD template](deprecations.md#opentofu-cicd-template) | Low | Deploy | Project |  |
| [CodeClimate-based Code Quality scanning will be removed](deprecations.md#codeclimate-based-code-quality-scanning-will-be-removed) | High | Secure |  | Refer to the [Understanding this change](https://gitlab.com/gitlab-org/gitlab/-/issues/471677#understanding-this-change) section for details. |
| [Replace `add_on_purchase` GraphQL field with `add_on_purchases`](deprecations.md#replace-add_on_purchase-graphql-field-with-add_on_purchases) | Low | Fulfillment | Instance, group |  |
| [Replace namespace `add_on_purchase` GraphQL field with `add_on_purchases`](deprecations.md#replace-namespace-add_on_purchase-graphql-field-with-add_on_purchases) | Low | Fulfillment | Instance, group |  |
| [Public use of Secure container registries is deprecated](deprecations.md#public-use-of-secure-container-registries-is-deprecated) | Low | Secure | Instance |  |
| [Limit number of scan execution policy actions allowed per policy](deprecations.md#limit-number-of-scan-execution-policy-actions-allowed-per-policy) | Low | Security risk management | Instance, group, project |  |
| [Deprecate CI job implementation of Repository X-Ray](deprecations.md#deprecate-ci-job-implementation-of-repository-x-ray) | Low | Create | Project |  |
| [Pipeline job limits extended to the Commits API](deprecations.md#pipeline-job-limits-extended-to-the-commits-api) | Low | Verify | Project |  |
| [Deprecation of `name` field in `ProjectMonthlyUsageType` GraphQL API](deprecations.md#deprecation-of-name-field-in-projectmonthlyusagetype-graphql-api) | Low | Fulfillment | Project |  |
| [Deprecation of `STORAGE` enum in `NamespaceProjectSortEnum` GraphQL API](deprecations.md#deprecation-of-storage-enum-in-namespaceprojectsortenum-graphql-api) | Low | Fulfillment | Group |  |
| [Workspaces `editor` GraphQL field is deprecated](deprecations.md#workspaces-editor-graphql-field-is-deprecated) | Low | Create | Project |  |
| [DAST `dast_devtools_api_timeout` will have a lower default value](deprecations.md#dast-dast_devtools_api_timeout-will-have-a-lower-default-value) | Low | Application security testing | Project |  |
| [API Discovery will use branch pipelines by default](deprecations.md#api-discovery-will-use-branch-pipelines-by-default) | Low | Application_security_testing | Project |  |
| [Container Scanning default severity threshold set to `medium`](deprecations.md#container-scanning-default-severity-threshold-set-to-medium) | Low | Application security testing | Project |  |
| [Subscription related API endpoints in the public API are deprecated](deprecations.md#subscription-related-api-endpoints-in-the-public-api-are-deprecated) | Low | Fulfillment | Instance |  |
| [GitLab Advanced SAST will be enabled by default](deprecations.md#gitlab-advanced-sast-will-be-enabled-by-default) | Medium | Application security testing | Instance |  |
| [The `agentk` container registry is moving to Cloud Native GitLab](deprecations.md#the-agentk-container-registry-is-moving-to-cloud-native-gitlab) | Medium | Deploy | Instance |  |
| [SAST jobs no longer use global cache settings](deprecations.md#sast-jobs-no-longer-use-global-cache-settings) | Medium | Application security testing | Instance |  |
| [End-of-Support SAST jobs will be removed from the CI/CD template](deprecations.md#end-of-support-sast-jobs-will-be-removed-from-the-cicd-template) | High | Application security testing | Project |  |
| [Application Security Testing analyzers major version update](deprecations.md#application-security-testing-analyzers-major-version-update) | Low | Application security testing | Project |  |

## Window 2

This window takes place on April 28 - 30, 2025 from 09:00 UTC to 22:00 UTC.

| Deprecation | Impact | Stage | Scope | Check potential impact |
|-------------|--------|-------|-------|------------------------|
| [Replace GraphQL field `take_ownership_pipeline_schedule` with `admin_pipeline_schedule` in PipelineSchedulePermissions](deprecations.md#replace-graphql-field-take_ownership_pipeline_schedule-with-admin_pipeline_schedule-in-pipelineschedulepermissions) | Low | Verify | Project |  |
| [The `heroku/builder:22` image is deprecated](deprecations.md#the-herokubuilder22-image-is-deprecated) | Medium | Deploy | Project |  |
| [`mergeTrainIndex` and `mergeTrainsCount` GraphQL fields deprecated](deprecations.md#mergetrainindex-and-mergetrainscount-graphql-fields-deprecated) | Low | Verify | Project |  |
| [Behavior change for Upcoming and Started milestone filters](deprecations.md#behavior-change-for-upcoming-and-started-milestone-filters) | Low | Plan | Group, project |  |
| [`kpt`-based `agentk` is deprecated](deprecations.md#kpt-based-agentk-is-deprecated) | Low | Deploy | Project |  |
| [Updating CI/CD job tokens to JWT standard](deprecations.md#updating-cicd-job-tokens-to-jwt-standard) | Low | Software supply chain security | Project |  |

## Window 3

This window takes place on May 5 - 7, 2025 from 09:00 UTC to 22:00 UTC.

| Deprecation | Impact | Stage | Scope | Check potential impact |
|-------------|--------|-------|-------|------------------------|
| [GitLab.com certificate-based integration with Kubernetes](deprecations.md#gitlabcom-certificate-based-integration-with-kubernetes) | Medium | Deploy |  |  |
| [GraphQL deprecation of `dependencyProxyTotalSizeInBytes` field](deprecations.md#graphql-deprecation-of-dependencyproxytotalsizeinbytes-field) | Low | Package | Group |  |
| [The `ci_job_token_scope_enabled` projects API attribute is deprecated](deprecations.md#the-ci_job_token_scope_enabled-projects-api-attribute-is-deprecated) | Low | Govern | Project |  |
| [Deprecate license metadata format V1](deprecations.md#deprecate-license-metadata-format-v1) | Low | Secure | Instance |  |
| [The `direction` GraphQL argument for `ciJobTokenScopeRemoveProject` is deprecated](deprecations.md#the-direction-graphql-argument-for-cijobtokenscoperemoveproject-is-deprecated) | Low | Govern | Project |  |
| [Replace `threshold` with `maxretries` for container registry notifications](deprecations.md#replace-threshold-with-maxretries-for-container-registry-notifications) | Low | Package | Project |  |
| [GraphQL `target` field for to-do items replaced with `targetEntity`](deprecations.md#graphql-target-field-for-to-do-items-replaced-with-targetentity) | Low | Foundations | Project |  |
| [`ciJobTokenScopeAddProject` GraphQL mutation is deprecated](deprecations.md#cijobtokenscopeaddproject-graphql-mutation-is-deprecated) | Low | Govern | Project |  |
| [Removal of `migrationState` field in `ContainerRepository` GraphQL API](deprecations.md#removal-of-migrationstate-field-in-containerrepository-graphql-api) | Low | Package | Project |  |
| [Updated tooling to release CI/CD components to the Catalog](deprecations.md#updated-tooling-to-release-cicd-components-to-the-catalog) | High | Verify | Instance |  |
| [Increased default security for use of pipeline variables](deprecations.md#increased-default-security-for-use-of-pipeline-variables) | Medium | Verify | Project |  |
| [Amazon S3 Signature Version 2](deprecations.md#amazon-s3-signature-version-2) | Low | Package | Project |  |
| [Dependency Proxy token scope enforcement](deprecations.md#dependency-proxy-token-scope-enforcement) | High | Package | Group |  |
| [Remove duoProAssignedUsersCount GraphQL field](deprecations.md#remove-duoproassigneduserscount-graphql-field) | Low | Plan | Group, project |  |
| [Remove `previousStageJobsOrNeeds` from GraphQL](deprecations.md#remove-previousstagejobsorneeds-from-graphql) | Low | Verify | Instance |  |
